@@ -364,3 +364,19 @@ async def test_query_focus_blur():
         # Focus non existing
         app.query("#egg").focus()
         assert app.focused.id == "bar"
+
+
+async def test_query_error():
+    class QueryApp(App):
+        def compose(self) -> ComposeResult:
+            yield Input(id="foo")
+
+    app = QueryApp()
+    async with app.run_test():
+        with pytest.raises(WrongType):
+            # Asking for a Label, but the widget is an Input
+            app.query_one("#foo", Label)
+
+        # Widget is an Input so this works
+        foo = app.query_one("#foo", Input)
+        assert isinstance(foo, Input)
